|docs| |pipelines|

################################################
Lagranto - A Library to work with trajectories.
################################################

A recent build of the documentation is available at https://lagranto.readthedocs.io/en/latest/

.. |docs| image:: https://readthedocs.org/projects/lagranto/badge/?version=latest
    :target: http://lagranto.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
    

.. |pipelines| image:: https://gitlab.com/atmosdyn/Lagranto/badges/master/pipeline.svg  
    :target: https://gitlab.com/atmosdyn/Lagranto/commits/master



Documentation
-------------

To compile the documentation the `sphinx` package have to be installed::

    conda install sphinx

To compile the html documentation::

    cd docs
    make html
